# spherenet

This will be an implementation of [Deep Hyperspherical Learning](https://arxiv.org/abs/1711.03189v1). Deep Hyperspherical Learning is a simple modification to the convolution operator that speeds up convergence and improves accuracy.
